<?php 

// Direct access to the file not allowed.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Lana Core Class
 *
 * @since 1.0.0
 */
class Lana_Core {
	
	/**
	 * Lana Version
	 *
	 * @since 1.0.0
	 */
	static $version = '2.0.2';
	
	/**
	 * Development Mode
	 *
	 * @since 1.0.0
	 */
	static $development = false;
	
	/**
	 * Class Constructor
	 *
	 * @since 1.0.0
	 */
	function __construct() {
		
		/**
		 * If development under progress,
		 * generate unique id for scripts
		 * and styles version.
		 *
		 * @since 1.0.0
		 */
		if( self::$development ) {
			self::$version = esc_attr( uniqid() );
		}
		
		$this->paths();
		
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts_n_styles' ) );
	}
	
	/**
	 * Define Theme Path's
	 *
	 * @since 1.0.0
	 */
	function paths() {
		// Lana Theme Root URI Path
		if( ! defined( 'Lana_URI' ) ) {
			define( 'Lana_URI', get_template_directory_uri() . '/' );
		}
		// Lana Theme Images URI Path
		if( ! defined( 'Lana_IMG_URI' ) ) {
			define( 'Lana_IMG_URI', Lana_URI . 'assets/img/' );
		}
		// Lana Theme CSS URI Path
		if( ! defined( 'Lana_CSS_URI' ) ) {
			define( 'Lana_CSS_URI', Lana_URI . 'assets/css/' );
		}
		// Lana Theme JS URI Path
		if( ! defined( 'Lana_JS_URI' ) ) {
			define( 'Lana_JS_URI', Lana_URI . 'assets/js/' );
		}
	}
	
	/**
	 * Enqueue Theme Scripts and Styles
	 *
	 * @since 1.0.0
	 */
	function scripts_n_styles() {
        
        /*
         * Adds JavaScript to pages with the comment form to support
         * sites with threaded comments (when in use).
         */
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }
		
		// FontAwesome
		wp_register_style( 'font-awesome', Lana_CSS_URI . 'font-awesome.min.css', array(), self::$version );
		wp_enqueue_style( 'font-awesome' );
		
		// Skel JS
		wp_register_script( 'lana-skel', Lana_JS_URI . 'skel.min.js', array( 'jquery' ), self::$version );
		wp_enqueue_script( 'lana-skel' );
		
		// Lana Util JS
		wp_register_script( 'lana-util', Lana_JS_URI . 'lana-util.js', array( 'jquery' ), self::$version );
		wp_enqueue_script( 'lana-util' );
		
		// Lana Main JS Functions
		wp_register_script( 'lana-functions', Lana_JS_URI . 'lana-functions.js', array( 'jquery' ), self::$version );
		wp_enqueue_script( 'lana-functions' );
		
		// Lana Theme Main Stylesheet
		wp_register_style( 'lana-style', get_stylesheet_uri(), array(), self::$version );
		wp_enqueue_style( 'lana-style' );
		
	}
	
}

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
