<?php 

// Direct access to the file not allowed.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! isset( $content_width ) ) {
    $content_width = 900;
}

/**
 * Lana After Setup Theme
 *
 * @since 1.0.0
 */
add_action( 'after_setup_theme', 'lana_after_setup_theme' );
function lana_after_setup_theme() {
	
	// Custom Logo Support
	$defaults['custom_logo'] = array(
		'height'		=> '',
		'width'			=> '',
		'flex_height'	=> true,
		'flex_width'	=> true,
		'header_text'	=> array( 'a.logo' )
	);
	add_theme_support( 'custom_logo', $defaults['custom_logo'] );
    
    // Adds support for title tag
	add_theme_support( 'title-tag' );
    
    // Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );
	
	// Register Main Menu
	register_nav_menu( 'lana_nav_primary', __( 'Primary Menu', 'lana' ) );
	
	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 800, 9999 ); // Unlimited height, soft crop
}

/**
 * Single Post Navigation (Prev / Next) Class
 *
 * @since 2.0
 */
add_filter('next_post_link', 'lana_posts_link_attributes');
add_filter('previous_post_link', 'lana_posts_link_attributes');
function lana_posts_link_attributes( $output ) {
    $code = 'class="btn btn-outline-secondary btn-sm"';
    return str_replace('<a href=', '<a '.$code.' href=', $output);
}

/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own lana_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since 1.0
 */
if ( ! function_exists( 'lana_comment' ) ) {
    function lana_comment( $comment, $args, $depth ) {
        $GLOBALS['comment'] = $comment;
        switch ( $comment->comment_type ) :
            case 'pingback' :
            case 'trackback' :
            // Display trackbacks differently than normal comments.
        ?>
        <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
            <p><?php _e( 'Pingback:', 'lana' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'lana' ), '<span class="edit-link">', '</span>' ); ?></p>
        <?php
                break;
            default :
            // Proceed with normal comments.
            global $post;
        ?>
        <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
            <div id="comment-<?php comment_ID(); ?>" class="comment-wrap clearfix">

                <div class="comment-meta">
                    <div class="comment-author vcard">
                        <span class="comment-avatar clearfix">
                            <?php echo get_avatar( $comment, 44 ); ?>
                        </span>
                    </div>
                </div>

                <div class="comment-content comment">
                    <div class="comment-author">
                    <?php
                    printf( '<a href="%1$s">%2$s %3$s</a>', get_permalink(), get_comment_author_link(),
                                // If current post author is also comment author, make it known visually.
                                ( $comment->user_id === $post->post_author ) ? '<cite>' . __( 'author', 'lana' ) . '</cite>' : ''
                    );
                    printf( '<span><a href="%1$s"><time datetime="%2$s">%3$s</time></a></span>',
                            esc_url( get_comment_link( $comment->comment_ID ) ),
                            get_comment_time( 'c' ),
                            /* translators: 1: date, 2: time */
                            sprintf( __( '%1$s at %2$s', 'lana' ), get_comment_date(), get_comment_time() )
                    );
                    ?>
                    </div>
                    <?php comment_text(); ?>
                    
                    <?php edit_comment_link( '' ); ?>
                    
                    <?php // Reply link.
                    comment_reply_link( 
                        array_merge( $args, 
                            array( 
                                'reply_text' => '', 
                                'depth'      => $depth, 
                                'max_depth'  => $args['max_depth']
                            ) 
                        ) 
                    ); ?>
                    
                </div>

                <?php if ( '0' == $comment->comment_approved ) : ?>
                    <p class="comment-awaiting-moderation"><i class="fa fa-spinner fa-pulse fa-fw"></i> <?php _e( 'Your comment is awaiting moderation.', 'lana' ); ?></p>
                <?php endif; ?>

            </div>
        <?php
            break;
        endswitch;
    }
}

/**
 * Comment Form Fields
 *
 * @since 2.0
 */
add_filter( 'comment_form_default_fields', 'lana_comment_form_fields' );
function lana_comment_form_fields( $fields ) {
	
	// Get the current commenter if available
    $commenter = wp_get_current_commenter();
	
	// Core functionality
    $req      = get_option( 'require_name_email' );
    $aria_req = ( $req ? " aria-required='true'" : '' );
    $html_req = ( $req ? " required='required'" : '' );
	
	$fields['author']	= '<div class="4u 12u$(xsmall)"><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" ' . $aria_req . ' placeholder="' . __( 'Name', 'lana' ) .'*"/></div>';
	$fields['email'] 	= '<div class="4u 12u$(xsmall)"><input id="email" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" ' . $aria_req . ' placeholder="' . __( 'Email', 'lana' ) . '*"/></div>';
	$fields['url'] 		= '<div class="4u 12u$(xsmall)"><input id="url" name="url" type="text" value="' . esc_url( $commenter['comment_author_url'] ) . '" placeholder="' . __( 'Website', 'lana' ) .'"/></div>';
	
	return $fields;
}

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
